==> qtjambi-scxml-debuginfo-linux-x64-5.15.17.jar: sources/QtJambiScxml/QScxmlStaticScxmlServiceFactory_shell.h <==
#ifndef QSCXMLSTATICSCXMLSERVICEFACTORY_SHELL_H
#define QSCXMLSTATICSCXMLSERVICEFACTORY_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtScxml/qscxmlinvokableservice.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/QVector>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtScxml/qscxmlexecutablecontent.h>
#include <QtScxml/qscxmlstatemachine.h>
#include <QtJambi/RegistryAPI>


class QScxmlStaticScxmlServiceFactory_shell : public QScxmlStaticScxmlServiceFactory, public QtJambiShellInterface
{
public:
    QScxmlStaticScxmlServiceFactory_shell(const QMetaObject* metaObject0, const QScxmlExecutableContent::InvokeInfo& invokeInfo1, const QVector<qint32>& nameList2, const QVector<QScxmlExecutableContent::ParameterInfo>& parameters3, QObject* parent4 = nullptr);
    ~QScxmlStaticScxmlServiceFactory_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QScxmlInvokableService* invoke(QScxmlStateMachine* parentStateMachine0) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QScxmlStaticScxmlServiceFactory_access : public QScxmlStaticScxmlServiceFactory
{
    jobject __qt_invoke_QScxmlStateMachine_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID parentStateMachine0);
};

#endif // QSCXMLSTATICSCXMLSERVICEFACTORY_SHELL_H

==> qtjambi-scxml-debuginfo-linux-x64-6.6.3.jar: sources/QtJambiScxml/QScxmlStaticScxmlServiceFactory_shell.h <==
#ifndef QSCXMLSTATICSCXMLSERVICEFACTORY_SHELL_H
#define QSCXMLSTATICSCXMLSERVICEFACTORY_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtScxml/qscxmlinvokableservice.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qvariant.h>
#include <QtScxml/qscxmlexecutablecontent.h>
#include <QtScxml/qscxmlstatemachine.h>
#include <QtJambi/RegistryAPI>


class QScxmlStaticScxmlServiceFactory_shell : public QScxmlStaticScxmlServiceFactory, public QtJambiShellInterface
{
public:
    QScxmlStaticScxmlServiceFactory_shell(const QMetaObject* metaObject0, const QScxmlExecutableContent::InvokeInfo& invokeInfo1, const QList<qint32>& nameList2, const QList<QScxmlExecutableContent::ParameterInfo>& parameters3, QObject* parent4 = nullptr);
    ~QScxmlStaticScxmlServiceFactory_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QScxmlInvokableService* invoke(QScxmlStateMachine* parentStateMachine0) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QScxmlStaticScxmlServiceFactory_access : public QScxmlStaticScxmlServiceFactory
{
    jobject __qt_invoke_QScxmlStateMachine_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID parentStateMachine0);
};

#endif // QSCXMLSTATICSCXMLSERVICEFACTORY_SHELL_H
